@@ -3,5 +3,7 @@ TEMPLATES = {
     "record-multilingual": "templates/invenio_record_multilingual.py.jinja2",
     "subschema-multilingual": "templates/invenio_schema_multilingual.py.jinja2",
     "multi-search": "templates/invenio_record_search_multilingual.py.jinja2",
-
-}
\ No newline at end of file
+    "subschema-i18n": "templates/invenio_schema_i18n.py.jinja2",
+    "ui-subschema-i18n": "templates/invenio_ui_schema_i18n.py.jinja2",
+    "ui-subschema-multilingual": "templates/invenio_ui_schema_multilingual.py.jinja2",
+}
