@@ -2,6 +2,6 @@ from oarepo_model_builder.invenio.invenio_base import InvenioBaseClassPythonBuil
 
 
 class InvenioSchemaMultilingualBuilder(InvenioBaseClassPythonBuilder):
-    TYPE = 'invenio_schema_multilingual'
-    class_config = 'multilingual-schema-class'
-    template = 'subschema-multilingual'
+    TYPE = "invenio_schema_multilingual"
+    class_config = "multilingual-schema-class"
+    template = "subschema-multilingual"
